import NodeTableComponent, {
  DataTemplateInterface,
} from "../NodeTableComponent/NodeTableComponent";

export default function FileHeader() {
  const dataTemplate: DataTemplateInterface = {
    machine: {
      name: "Machine",
      offset: 0,
      size: 2,
      value: null,
      data_type: "hex",
    },
    number_of_sections: {
      name: "Number of Sections",
      offset: 2,
      size: 2,
      value: null,
      data_type: "hex",
    },
    time_date_stamp: {
      name: "Time Date Stamp",
      offset: 4,
      size: 4,
      value: null,
      data_type: "hex",
    },
    pointer_to_symbol_table: {
      name: "Pointer to Symbol Table",
      offset: 8,
      size: 4,
      value: null,
      data_type: "hex",
    },
    number_of_symbols: {
      name: "Number of Symbols",
      offset: 12,
      size: 4,
      value: null,
      data_type: "hex",
    },
    size_of_optional_header: {
      name: "Size of Optional Header",
      offset: 16,
      size: 2,
      value: null,
      data_type: "hex",
    },
    characteristics: {
      name: "Characteristics",
      offset: 18,
      size: 2,
      value: null,
      data_type: "enum",
      enum: {
        0x1: {
          enum_name: "RELOCS_STRIPPED",
          description: "Relocation info stripped from file.",
        },
        0x2: {
          enum_name: "EXECUTABLE_IMAGE",
          description:
            "File is executable (i.e. no unresolved external references).",
        },
        0x4: {
          enum_name: "LINE_NUMS_STRIPPED",
          description: "Line nunbers stripped from file.",
        },
        0x8: {
          enum_name: "LOCAL_SYMS_STRIPPED",
          description: "Local symbols stripped from file.",
        },
        0x10: {
          enum_name: "AGGRESSIVE_WS_TRIM",
          description: "Aggressively trim working set",
        },
        0x20: {
          enum_name: "LARGE_ADDRESS_AWARE",
          description: "App can handle >2gb addresses",
        },
        0x80: {
          enum_name: "BYTES_REVERSED_LO",
          description: "Bytes of machine word are reversed.",
        },
        0x100: {
          enum_name: "MACHINE_32BIT",
          description: "32 bit word machine.",
        },
        0x200: {
          enum_name: "DEBUG_STRIPPED",
          description: "Debugging info stripped from file in .DBG file",
        },
        0x400: {
          enum_name: "REMOVABLE_RUN_FROM_SWAP",
          description:
            "If Image is on removable media, copy and run from the swap file.",
        },
        0x800: {
          enum_name: "NET_RUN_FROM_SWAP",
          description: "If Image is on Net, copy and run from the swap file.",
        },
        0x1000: {
          enum_name: "SYSTEM",
          description: "System File.",
        },
        0x2000: {
          enum_name: "DLL",
          description: "File is a DLL.",
        },
        0x4000: {
          enum_name: "UP_SYSTEM_ONLY",
          description: "File should only be run on a UP machine",
        },
        0x8000: {
          enum_name: "BYTES_REVERSED_HI",
          description: "Bytes of machine word are reversed.",
        },
      },
    },
  };
  const command = "command_get_pe_data_file_header";
  const columns = [
    {
      title: "字段名",
      dataIndex: "name",
      key: "name",
    },
    {
      title: "偏移",
      dataIndex: "offset",
      key: "offset",
      hexSwitch: true,
    },
    {
      title: "大小",
      dataIndex: "size",
      key: "size",
    },
    {
      title: "值",
      dataIndex: "value",
      key: "value",
      hexSwitch: true,
      editable: true,
    },
    {
      title: "描述信息",
      dataIndex: "description",
      key: "description",
    },
  ];
  return (
    <NodeTableComponent
      dataTemplate={dataTemplate}
      command={command}
      columns={columns as any}
    ></NodeTableComponent>
  );
}
