import styles from "./MainPage.module.scss";
import { useEffect, useState } from "react";
import { Layout, Flex, Button, Empty } from "antd";
import { listen } from "@tauri-apps/api/event";
import { invoke } from "@tauri-apps/api/core";
const { Content } = Layout;
import { SaveOutlined, FolderOpenFilled } from "@ant-design/icons";
import SiderTree from "../components/side_tree/SideTree";
import DosHeader from "../components/DosHeader/DosHeader";
import NtHeader from "../components/NTHeader/NTHeader";
import FileHeader from "../components/FileHeader/FileHeader";
import OptionalHeader from "../components/OptionalHeader/OptionalHeader";
import NodeTableComponent, {
  DataTemplateInterface,
} from "../components/NodeTableComponent/NodeTableComponent";
import { open } from "@tauri-apps/plugin-dialog";

const SelectNodeMap = {
  dos_header: <DosHeader />,
  nt_header: <NtHeader />,
  file_header: <FileHeader />,
  optional_header: <OptionalHeader />,
};

export default function MainPage() {
  const [treeData, setTreeData] = useState([]);
  const [filePath, setFilePath] = useState("");
  const [selectedKey, setSelectedKey] = useState("");

  const openFile = async () => {
    const file = await open({
      multiple: false,
      directory: false,
    });
    if (file) {
      setFilePath(file);
    }
  };

  const changeFile = (filePath: string) => {
    invoke("command_open_file", { filePath }).then(() => {
      invoke("command_get_file_pe_node_tree_data").then((res) => {
        setTreeData(res as any);
      });
    });
  };

  const onSelect = (newSelectedKey) => {
    setSelectedKey(newSelectedKey);
  };

  useEffect(() => {
    const unlisten = listen<{ paths: Array<string> }>(
      "tauri://drag-drop",
      (event) => {
        const filePath = event.payload.paths[0];
        setFilePath(filePath);
      }
    );
    return () => {
      unlisten.then((f) => f());
    };
  }, []);

  useEffect(() => {
    if (filePath) {
      changeFile(filePath);
    }
  }, [filePath]);

  return (
    <Layout className={styles.mainLayout}>
      <Flex className={styles.header}>
        <Button
          style={{
            marginRight: "10px",
          }}
          type="dashed"
          onClick={openFile}
          icon={<FolderOpenFilled></FolderOpenFilled>}
        >
          打开新文件
        </Button>
        <Button type="primary" icon={<SaveOutlined></SaveOutlined>}>
          保存
        </Button>
      </Flex>
      <Flex
        style={{
          backgroundColor: "#e5e5e5",
          paddingBottom: "16px",
          height: "100%",
        }}
      >
        <Flex className={styles.sider}>
          <SiderTree
            treeData={treeData}
            defaultSelectedKey={treeData[0]?.key || ""}
            onSelect={onSelect}
          />
        </Flex>
        <Content className={styles.content}>
          {selectedKey && SelectNodeMap[selectedKey] ? (
            SelectNodeMap[selectedKey]
          ) : (
            <Empty description={"请选择一个节点"} />
          )}
          {/* <TestNodeTableComponent></TestNodeTableComponent> */}
        </Content>
      </Flex>
    </Layout>
  );
}

const TestNodeTableComponent = () => {
  const [sortStatus, setSortStatus] = useState<"ascend" | "descend" | null>(
    "ascend"
  );
  const dataTemplate: DataTemplateInterface = {
    e_magic: {
      name: "e_magic",
      value: 0,
      size: 2,
      offset: 0,
      description: "Magic number",
      data_type: "hex",
    },
    e_res: {
      name: "e_res",
      value: null,
      size: 8,
      offset: 28,
      description: "Reserved",
      data_type: "array",
      array_element_size: 2,
    },
    test_enum: {
      name: "test_enum",
      value: 0,
      size: 2,
      offset: 10,
      description: "Test enum",
      data_type: "enum",
      enum: {
        1: {
          enum_name: "enum1",
          description: "enum1 description",
        },
        2: {
          enum_name: "enum2",
          description: "enum2 description",
        },
        4: {
          enum_name: "enum4",
          description: "enum4 description",
        },
        8: {
          enum_name: "enum8",
          description: "enum8 description",
        },
      },
    },
  };

  const command = "test_command";
  const columns = [
    {
      title: "Name",
      dataIndex: "name",
      key: "name",
    },
    {
      title: "偏移",
      dataIndex: "offset",
      hexSwitch: true,
      key: "offset",
      sortOrder: sortStatus,
    },
    {
      title: "大小",
      dataIndex: "size",
      key: "size",
    },
    {
      title: "值",
      dataIndex: "value",
      hexSwitch: true,
      editable: true,
      key: "value",
    },
    {
      title: "描述",
      dataIndex: "description",
      key: "description",
    },
  ];

  return (
    <>
      <NodeTableComponent
        dataTemplate={dataTemplate}
        command={command}
        columns={columns as any}
      ></NodeTableComponent>
    </>
  );
};
